// WindowPosition.cpp: implementation of the WindowPosition class.
//
//////////////////////////////////////////////////////////////////////
#include "stdafx.h"
#include "WindowPosition.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////
WindowPosition::WindowPosition(HKEY hKey,TCHAR* szSubKey)
{
  m_dwPosArray[0] = m_dwPosArray[1] = m_dwPosArray[2] = m_dwPosArray[3] = m_dwPosArray[4];
  m_hKey = NULL;
  _tcscpy(m_szSubKey,szSubKey);
  //try to create the key here..if it exists, this will open the key
  if(ERROR_SUCCESS != RegCreateKeyEx(hKey,m_szSubKey,0,NULL,REG_OPTION_NON_VOLATILE,KEY_ALL_ACCESS,NULL,&m_hKey,NULL))
    m_hKey = NULL;
}

WindowPosition::~WindowPosition()
{
  if(NULL != m_hKey)
  {
    RegCloseKey(m_hKey);
    m_hKey = NULL;
  }
}

//returns the window positions from registry
BOOL WindowPosition::GetWindowPositions(DWORD& dwxPos,DWORD& dwyPos,DWORD& dwWidth,DWORD& dwHeight)
{
  BOOL bRet = FALSE;

  if(NULL != m_hKey)
  {
    //get the MainWindowPosition value data
    DWORD dwType = REG_BINARY;
    DWORD dwcbData = 5*sizeof(DWORD);
    if(ERROR_SUCCESS == RegQueryValueEx(m_hKey,_T("MainWindowPositions"),NULL,&dwType,(LPBYTE)m_dwPosArray,&dwcbData))
    {
      //if data size looks screwed up... return FALSE
      if(5*sizeof(DWORD) == dwcbData && TRUE == ValidatePositions(m_dwPosArray[0],m_dwPosArray[1],m_dwPosArray[2],m_dwPosArray[3],m_dwPosArray[4]))
      {
        dwxPos = m_dwPosArray[0];
        dwyPos = m_dwPosArray[1];
        dwWidth = m_dwPosArray[2];
        dwHeight = m_dwPosArray[3];
        bRet = TRUE;
      }
    }
  }
  return bRet;
}

//sets the window positions into memory
void WindowPosition::OnWindowPosChanged( WINDOWPOS* lpwndpos)
{
  m_dwPosArray[0] = (DWORD)lpwndpos->x;
  m_dwPosArray[1] = (DWORD)lpwndpos->y;
  m_dwPosArray[2] = (DWORD)lpwndpos->cx;
  m_dwPosArray[3] = (DWORD)lpwndpos->cy;
  m_dwPosArray[4] = m_dwPosArray[0] + m_dwPosArray[1] + m_dwPosArray[2] + m_dwPosArray[3];
 
}

//saves the current positions into registry
BOOL WindowPosition::SaveWindowPositions()
{
  BOOL bRet = FALSE;
  if(NULL != m_hKey)
  {
    //set the MainWindowPosition value data
    DWORD dwType = REG_BINARY;
    DWORD dwcbData = 5*sizeof(DWORD);
    if(ERROR_SUCCESS == RegSetValueEx(m_hKey,_T("MainWindowPositions"),NULL,dwType,(LPBYTE)m_dwPosArray,dwcbData))
    {
      bRet = TRUE;
    }
  }
  return bRet;
}

//private method for implementing a Is_data_corrupted check
BOOL WindowPosition::ValidatePositions(DWORD& dwxPos,DWORD& dwyPos,DWORD& dwWidth,DWORD& dwHeight,DWORD& dwSum)
{
  if(dwSum == (dwxPos + dwyPos + dwWidth + dwHeight))
  {
    return TRUE;
  }
  else
  {
    return FALSE;
  }
}

